GradientDesc

Struct GradientDesc 

pub struct GradientDesc<'a> {
    pub kind: GradientKind,
    pub stops: &'a [(u8, Color)],
}
Linear or radial gradient descriptor.

Stops are (position, color) pairs where position is 0..=255. At most GRADIENT_MAX_STOPS stops are considered; extra stops are ignored by the software reference path. Stops do not need to be sorted.

Fields

kind: GradientKind

Gradient geometry.

stops: &'a [(u8, Color)]

Color stops in 0..=255 position space.

Implementations

Source

impl<'a> GradientDesc<'a>

pub const fn new(kind: GradientKind, stops: &'a [(u8, Color)]) -> Self

Create a gradient descriptor.

pub fn color_at(&self, rect: Rect, x: i32, y: i32) -> Option<Color>

Return the sampled color at an absolute pixel coordinate.