pub struct WrappedLine {
pub start: usize,
pub end: usize,
pub advance_fp16: i32,
}Expand description
One line produced by greedy wrapping.
Fields
start: usizeByte offset where the line starts in the original string.
end: usizeByte offset where the line ends in the original string.
advance_fp16: i32Measured line advance in 1/16 pixel units.