pub struct FlexConfig {
pub flow: FlexFlow,
pub main_align: FlexAlign,
pub cross_align: FlexAlign,
pub track_cross_align: FlexAlign,
pub gap_main: i32,
pub gap_cross: i32,
}Expand description
Flex engine configuration stored in a container’s LayoutState
(LPAR-10 5.D).
Configure a container node with
ObjectNode::set_layout_flex.
Fields
flow: FlexFlowMain-axis flow direction.
main_align: FlexAlignMain-axis alignment of items within a track.
cross_align: FlexAlignCross-axis alignment of items within a track.
track_cross_align: FlexAlignAlignment of tracks on the cross axis (multi-line only).
gap_main: i32Gap between items on the main axis in pixels.
gap_cross: i32Gap between tracks on the cross axis in pixels.