pub enum FadeDirection {
LeftToRight,
RightToLeft,
TopToBottom,
BottomToTop,
}Expand description
Direction of a linear FadeMask ramp.
Variants
LeftToRight
Start opacity is at the left edge and end opacity is at the right edge.
RightToLeft
Start opacity is at the right edge and end opacity is at the left edge.
TopToBottom
Start opacity is at the top edge and end opacity is at the bottom edge.
BottomToTop
Start opacity is at the bottom edge and end opacity is at the top edge.