pub enum Disposition {
Consumed,
Unconsumed,
NoTarget,
}Expand description
The outcome of a dispatch_object_event call.
Variants
Consumed
The event was consumed by a handler during dispatch.
Unconsumed
The event completed all phases without any handler consuming it.
NoTarget
No target could be resolved (no hit-test result or no focused node).