#[non_exhaustive]pub enum FlexAlign {
Start,
End,
Center,
SpaceEvenly,
SpaceAround,
SpaceBetween,
}Expand description
Alignment mode used for flex main-axis, cross-axis, and track-cross alignment (LPAR-10 5.D).
Registration policy
Specification Required — adding a variant requires a phase-doc entry citing and updating the 5.D table.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Start
Items/tracks packed toward the start of the axis (LV_FLEX_ALIGN_START).
End
Items/tracks packed toward the end of the axis (LV_FLEX_ALIGN_END).
Center
Items/tracks centered on the axis (LV_FLEX_ALIGN_CENTER).
SpaceEvenly
Equal space between and around items (LV_FLEX_ALIGN_SPACE_EVENLY).
SpaceAround
Half-space before first and after last, equal between
(LV_FLEX_ALIGN_SPACE_AROUND).
SpaceBetween
No space before first / after last, equal between
(LV_FLEX_ALIGN_SPACE_BETWEEN).